@@ -1,27 +1,14 @@
 /*
-    Copyright (C) 2019 Vlad Zahorodnii <vlad.zahorodnii@kde.org>
-    Copyright (C) 2020 Arjen Hiemstra <ahiemstra@heimr.nl>
+    SPDX-FileCopyrightText: 2019 Vlad Zahorodnii <vlad.zahorodnii@kde.org>
+    SPDX-FileCopyrightText: 2020 Arjen Hiemstra <ahiemstra@heimr.nl>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "Sensor.h"
 
-#include <optional>
 #include <chrono>
+#include <optional>
 
 #include <QEvent>
 
@@ -32,7 +19,6 @@
 #include "SensorDaemonInterface_p.h"
 #include "SensorQuery.h"
 
-
 using namespace KSysGuard;
 namespace chrono = std::chrono;
 
@@ -216,7 +202,7 @@ void Sensor::setEnabled(bool newEnabled)
 
 uint Sensor::updateInterval() const
 {
-    //TODO: Make this dynamic once the backend supports that.
+    // TODO: Make this dynamic once the backend supports that.
     return BackendUpdateInterval;
 }
 
